#include "g_graphx.c"

#define SEG1 0x1A20
#define SEG2 0x1A60
#define SEG3 0x1AA0
#define SEG4 0x1AE0
#define SEG5 0x1B20
#define SEG6 0x1B60
#define SEG7 0x1BA0

unsigned a,b;


// Gestion des segments: copie
void copyscreen(unsigned int sego, unsigned int segd);

// Par Superna, affiche une image
typedef unsigned char BMPTabType[1024];
void disp_bmp(BMPTabType BmpTab,unsigned int segm);


// Efface le buffer choisi.
void clear(unsigned int segm);

// Efface le buffer choisi.
void dbclear(unsigned int segm);

// Par Libithium, met le buffer voulu comme adresse d'origine
void movevideo(unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// OR sans clipping, au buffer voulu.
void d8_or(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// AND (masque) sans clipping, au buffer voulu.
void d8_and(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// XOR sans clipping, au buffer voulu.
void d8_xor(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// OR avec clipping, au buffer voulu.
void d8clip_or(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// AND avec clipping, au buffer voulu.
void d8clip_and(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 8*8 pour mode D3 ou DB avec
// XOR avec clipping, au buffer voulu.
void d8clip_xor(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec OR sans clipping, au buffer voulu.
void d16_or(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec AND sans clipping, au buffer voulu.
void d16_and(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec XOR sans clipping, au buffer voulu.
void d16_xor(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec OR avec clipping, au buffer voulu.
void d16clip_or(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec AND avec clipping, au buffer voulu.
void d16clip_and(int x,int y,void* spr,unsigned int segm);

// Affiche un sprite 16*16 pour mode D3 ou DB
// avec XOR avec clipping, au buffer voulu.
void d16clip_xor(int x,int y,void* spr,unsigned int segm);

/* ---------------------------------------
           Fonctions concernant la
             gestion d'une ligne
   --------------------------------------- */


// Affiche une ligne verticale noire en mode DB.
void bvline(unsigned int x,unsigned int ymin,unsigned int ymax,unsigned int segm);

// Affiche une ligne verticale blanche en mode DB.
void wvline(unsigned int x,unsigned int ymin,unsigned int ymax,unsigned int segm);

// Affiche une ligne verticale grise en mode DB.
void gvline(unsigned int x,unsigned int ymin,unsigned int ymax,unsigned int segm);

// Inverse une ligne verticale en mode DB.
void invvline(unsigned int x,unsigned int ymin,unsigned int ymax,unsigned int segm);

// Affiche une ligne verticale en mode DB avec la couleur choisie.
// Vitesse incomparable par rapport a une fonction du type :
// for (...) pxl(...);
void vline(unsigned int x,unsigned int ymin,unsigned int ymax,unsigned char couleur,unsigned int segm);

// Affiche une ligne horizontale noire en mode DB.
void bhline(unsigned int xmin,unsigned int xmax,unsigned int y,unsigned int segm);

// Affiche une ligne horizontale blanche en mode DB.
void whline(unsigned int xmin,unsigned int xmax,unsigned int y,unsigned int segm);

// Affiche une ligne horizontale grise en mode DB.
void ghline(unsigned int xmin,unsigned int xmax,unsigned int y,unsigned int segm);

// Inverse une ligne horizontale en mode DB.
void invhline(unsigned int xmin,unsigned int xmax,unsigned int y,unsigned int segm);

// Affiche une ligne horizontale en mode DB avec la couleur choisie.
// Vitesse incomparable par rapport a une fonction du type :
// for (...) pxl(...);
void hline(unsigned int xmin,unsigned int xmax,unsigned int y,unsigned char couleur,unsigned int segm);

/* ---------------------------------------
       Fonctions concernant la gestion
               d'un seul pixel
   --------------------------------------- */


// Dessine un pixel noir en mode DB
void bpxl(unsigned int x,unsigned char y,unsigned int segm);

// Dessine un pixel blanc en mode DB
void wpxl(unsigned int x,unsigned char y,unsigned int segm);

// Dessine un pixel gris en mode DB
void gpxl(unsigned int x,unsigned char y,unsigned int segm);

// Inverse un pixel en mode DB
void invpxl(unsigned int x,unsigned char y,unsigned int segm);

// Determine si le pixel est allume ou eteint
// en mode D3 ou DB, sur un seul buffer.
unsigned char pxltest(unsigned int x,unsigned char y,unsigned int segm);

// Dessine un pixel en fonction de la couleur (ou inversion) choisie.
void pxl(unsigned int x,unsigned char y,unsigned char couleur,unsigned int segm);

/* ---------------------------------------
           Fonctions de scrolling
   --------------------------------------- */


// Decale tout le buffer choisi(segm) vers la gauche et
// rajoute la colonne designee par x sur le buffer choisi
// (srcsegm).Relativement lent.
void rightscroll(unsigned int x,unsigned int srcsegm,unsigned int segm);

// Decale tout le buffer choisi(segm) vers la droite et
// rajoute la colonne designee par x du buffer choisi
// (srcsegm) sur l'autre buffer choisi(segm).
// Relativement lent.
void leftscroll(unsigned int x,unsigned int srcsegm,unsigned int segm);

// Decale tout le buffer choisi(segm) vers le bas et
// rajoute la ligne designee par y du buffer choisi
// (srcsegm) sur l'autre buffer choisi(segm).
// Relativement lent.
void upscroll(unsigned int y,unsigned int srcsegm,unsigned int segm);

// Decale tout le buffer choisi(segm) vers le haut et
// rajoute la ligne designee par y du buffer choisi
// (srcsegm) sur l'autre buffer choisi(segm).
// Relativement lent.
void downscroll(unsigned int y,unsigned int srcsegm,unsigned int segm);

